@@ -11,6 +11,8 @@ except DistributionNotFound:
 finally:
     del get_distribution, DistributionNotFound
 
+from . import plot
 from .vis_cpu import vis_cpu
 from .vis_gpu import HAVE_CUDA as HAVE_GPU
 from .vis_gpu import vis_gpu
+from .wrapper import simulate_vis
